@@ -31,6 +31,7 @@ from fresco.util.http import encode_multipart
 from fresco.util.urls import normpath, make_query
 from fresco.util.common import fq_path
 from fresco.util.wsgi import make_environ
+from fresco.typing import WSGICallable
 
 from fresco.exceptions import ResponseException
 from fresco.requestcontext import context
@@ -113,9 +114,7 @@ class FrescoApp(RouteCollection):
         #: If a function returns a value (other than ``None``),
         #: this value will be
         #: returned as the response instead of calling the scheduled view.
-        self.process_http_error_response_handlers: List[
-            Tuple[int, Callable]
-        ] = []
+        self.process_http_error_response_handlers: List[Tuple[int, Callable]] = []
 
         #: Functions to be called if an exception is raised during a view
         #: Each function will be passed ``request, exc_info``.
@@ -146,9 +145,7 @@ class FrescoApp(RouteCollection):
         clsname = self.__class__.__name__
         return "<%s %s>" % (
             clsname,
-            ("\n" + " " * (len(clsname) + 2)).join(
-                str(r) for r in self.__routes__
-            ),
+            ("\n" + " " * (len(clsname) + 2)).join(str(r) for r in self.__routes__),
         )
 
     def get_response(
@@ -214,15 +211,11 @@ class FrescoApp(RouteCollection):
                     response = None
                     for f in self.process_view_handlers:
                         try:
-                            r = f(
-                                request, view, traversal.args, traversal.kwargs
-                            )
+                            r = f(request, view, traversal.args, traversal.kwargs)
                             if r is not None:
                                 response = r
                         except Exception:
-                            return self.handle_exception(
-                                request, allow_reraise=False
-                            )
+                            return self.handle_exception(request, allow_reraise=False)
                     if response is not None:
                         if isinstance(response, Response):
                             return response
@@ -243,8 +236,7 @@ class FrescoApp(RouteCollection):
                     error_response = error_response or e.response
                     if (
                         route.fallthrough_statuses
-                        and error_response.status_code
-                        in route.fallthrough_statuses
+                        and error_response.status_code in route.fallthrough_statuses
                     ):
                         continue
 
@@ -284,7 +276,7 @@ class FrescoApp(RouteCollection):
 
         return Response.not_found()
 
-    def view(self, request=None):
+    def view(self, request=None) -> Response:
         request = request or context.request
         response = self.get_response(request=request)
 
@@ -351,8 +343,7 @@ class FrescoApp(RouteCollection):
             )
 
         have_error_handlers = self.process_exception_handlers or any(
-            st in (None, 500)
-            for st, fn in self.process_http_error_response_handlers
+            st in (None, 500) for st, fn in self.process_http_error_response_handlers
         )
 
         # Backwards compatibility: if no exception or 500 http error
@@ -402,9 +393,7 @@ class FrescoApp(RouteCollection):
                            :meth:`add_middleware`.
         """
         self.reset_wsgi_app()
-        self._middleware = [
-            m for m in self._middleware if m[0] is not middleware
-        ]
+        self._middleware = [m for m in self._middleware if m[0] is not middleware]
 
     def insert_middleware(self, position, middleware, *args, **kwargs):
         """
@@ -423,7 +412,7 @@ class FrescoApp(RouteCollection):
         self.reset_wsgi_app()
         self._middleware.insert(position, (middleware, args, kwargs))
 
-    def make_wsgi_app(self, wsgi_app=None, use_middleware=True):
+    def make_wsgi_app(self, wsgi_app=None, use_middleware=True) -> WSGICallable:
         """
         Return a WSGI (PEP-3333) compliant application that drives this
         FrescoApp object.
@@ -668,20 +657,16 @@ class FrescoApp(RouteCollection):
 
         environ = make_environ(url, environ, wsgi_input, **kwargs)
         app = self.make_wsgi_app(wsgi_app=fake_app, use_middleware=middleware)
-        content_iterator = app(environ, fake_start_response)
+        result = app(environ, fake_start_response)
+        close = getattr(result, "close", lambda: None)
+        content_iterator = iter(result)
         next(content_iterator, None)
         yield context
         list(content_iterator)
-        getattr(content_iterator, "close", lambda: None)()
+        close()
 
     def requestcontext_with_payload(
-        self,
-        url="/",
-        data=None,
-        environ=None,
-        files=None,
-        multipart=False,
-        **kwargs
+        self, url="/", data=None, environ=None, files=None, multipart=False, **kwargs
     ):
 
         if files:
@@ -700,14 +685,10 @@ class FrescoApp(RouteCollection):
         if "CONTENT_LENGTH" not in kwargs:
             kwargs["CONTENT_LENGTH"] = str(len(wsgi_input))
 
-        return self.requestcontext(
-            url, environ, wsgi_input=wsgi_input, **kwargs
-        )
+        return self.requestcontext(url, environ, wsgi_input=wsgi_input, **kwargs)
 
     def requestcontext_post(self, *args, **kwargs):
-        return self.requestcontext_with_payload(
-            REQUEST_METHOD="POST", *args, **kwargs
-        )
+        return self.requestcontext_with_payload(REQUEST_METHOD="POST", *args, **kwargs)
 
     def requestcontext_put(self, *args, **kwargs):
         kwargs["REQUEST_METHOD"] = "PUT"
