@@ -322,10 +322,10 @@ class MultiDict(MutableMapping):
 
         Updating from another MultiDict:
 
-            >>> d = MultiDict([('name', 'eric'), ('occupation', 'lumberjack')])
+            >>> d = MultiDict([('name', 'eric'), ('job', 'lumberjack')])
             >>> d.update(MultiDict([('mood', 'okay')]))
             >>> d
-            MultiDict([('name', 'eric'), ('occupation', 'lumberjack'), ('mood', 'okay')])
+            MultiDict([('name', 'eric'), ('job', 'lumberjack'), ('mood', 'okay')])
 
         from a dictionary:
 
