@@ -78,6 +78,7 @@ class Options(dict):
         tags: Sequence[str] = [],
         use_environ=False,
         strict=True,
+        dir=None,
     ):
         """
         Find all files matching glob pattern ``sources`` and populates the
@@ -124,8 +125,13 @@ class Options(dict):
             raise OptionsLoadedException("Options have already been loaded")
         hostname = gethostname().replace(".", "_")
         candidates: List[Path] = []
+        if dir is None:
+            dir = Path(".")
+        else:
+            dir = Path(dir)
+
         for source in sources.split(";"):
-            sourcepath = Path(source.strip())
+            sourcepath = dir / Path(source.strip())
             candidates.extend(
                 p
                 for p in sourcepath.parent.glob(sourcepath.name)
@@ -242,9 +248,7 @@ class Options(dict):
             self.update((k, d[k]) for k in d["__all__"])
         else:
             self.update(
-                (k, v)
-                for k, v in d.items()
-                if isinstance(k, str) and k and k[0] != "_"
+                (k, v) for k, v in d.items() if isinstance(k, str) and k and k[0] != "_"
             )
 
     def update_from_object(self, ob, load_all=False):
