@@ -177,8 +177,7 @@ class Request(object):
             return body.decode(encoding)
         except UnicodeDecodeError:
             raise exceptions.RequestParseError(
-                "Payload contains data that could not be decoded using "
-                + encoding
+                "Payload contains data that could not be decoded using " + encoding
             )
 
     def get_json(self, *args, **kwargs):
@@ -203,9 +202,7 @@ class Request(object):
         """
         if self._files is None:
             self._files = MultiDict(
-                (k, v)
-                for k, v in self.form.allitems()
-                if isinstance(v, FileUpload)
+                (k, v) for k, v in self.form.allitems() if isinstance(v, FileUpload)
             )
         return self._files
 
@@ -242,11 +239,31 @@ class Request(object):
             raise KeyError(key)
         return v
 
-    def get(self, key, default=None):
+    def get(self, key, default=_marker, type=None):
         """
-        Look up ``key`` in submitted form values
+        Look up ``key`` in submitted form values.
+
+        :param type: The type to which the returned result should be converted
+        :param default: The value produced if the argument is missing
+
+        If ``type`` is specified and the value cannot be converted to the given
+        type, or the value is not present and and no default value has been
+        specified, then a :class:`fresco.exceptions.BadRequest` error is raised.
         """
-        return self.form.get(key, default)
+        default_specified = default is not _marker
+        value = self.form.get(key, default)
+        if value is default:
+            if default_specified:
+                return default
+            if type is None:
+                return None
+
+        if type is None:
+            return value
+        try:
+            return type(value)
+        except (TypeError, ValueError):
+            raise exceptions.BadRequest()
 
     def getlist(self, key):
         """
@@ -262,19 +279,7 @@ class Request(object):
         default is specified, :class:`~fresco.exceptions.BadRequest` will be
         raised.
         """
-        v = self.get(key, _marker)
-        if v is _marker:
-            if default is _marker:
-                raise exceptions.BadRequest()
-            else:
-                return default
-        try:
-            return int(v)
-        except Exception:
-            if default is _marker:
-                raise exceptions.BadRequest()
-            else:
-                return default
+        return self.get(key, default, type=int)
 
     def __contains__(self, key):
         """
@@ -340,9 +345,7 @@ class Request(object):
         This method expects the former style (eg ``If-Modified-Since``) and is
         not case sensitive.
         """
-        return self.environ.get(
-            "HTTP_" + name.upper().replace("-", "_"), default
-        )
+        return self.environ.get("HTTP_" + name.upper().replace("-", "_"), default)
 
     @property
     def path(self):
@@ -350,8 +353,7 @@ class Request(object):
         Return the path component of the requested URL
         """
         return environ_to_str(
-            self.environ.get("SCRIPT_NAME", "")
-            + self.environ.get("PATH_INFO", "")
+            self.environ.get("SCRIPT_NAME", "") + self.environ.get("PATH_INFO", "")
         )
 
     @property
@@ -430,9 +432,7 @@ class Request(object):
             host = environ_to_str(self.environ["SERVER_NAME"])
             port = environ_to_str(self.environ["SERVER_PORT"])
 
-        if (scheme == "http" and port == "80") or (
-            scheme == "https" and port == "443"
-        ):
+        if (scheme == "http" and port == "80") or (scheme == "https" and port == "443"):
             netloc = host
         else:
             netloc = host + ":" + port
@@ -455,9 +455,7 @@ class Request(object):
         Note that PATH_INFO is already unquoted by the server
         """
         try:
-            return environ_to_str(
-                self.environ.get("PATH_INFO", ""), self.charset
-            )
+            return environ_to_str(self.environ.get("PATH_INFO", ""), self.charset)
         except UnicodeDecodeError:
             raise exceptions.BadRequest
 
@@ -469,15 +467,14 @@ class Request(object):
         Note that SCRIPT_NAME is already unquoted by the server
         """
         try:
-            return environ_to_str(
-                self.environ.get("SCRIPT_NAME", ""), self.charset
-            )
+            return environ_to_str(self.environ.get("SCRIPT_NAME", ""), self.charset)
         except UnicodeDecodeError:
             raise exceptions.BadRequest
 
     @property
     def query_string(  # type: ignore
-        self, environ_to_str=environ_to_str,
+        self,
+        environ_to_str=environ_to_str,
     ) -> Optional[str]:
         """\
         The QUERY_STRING value as a unicode string
