@@ -42,7 +42,6 @@ magicmethods = [
     "__coerce__",
     "__complex__",
     "__contains__",
-    "__del__",
     "__delattr__",
     "__delete__",
     "__delitem__",
@@ -249,9 +248,7 @@ class RequestArg(RouteArg):
         self.formkey = key
         self.is_list = isinstance(converter, list)
         if self.is_list:
-            self.converter = lambda vs: [
-                c(v) for c, v in zip(cycle(converter), vs)
-            ]
+            self.converter = lambda vs: [c(v) for c, v in zip(cycle(converter), vs)]
         else:
             self.converter = converter
 
@@ -269,9 +266,7 @@ class RequestArg(RouteArg):
         except KeyError:
             if self.required:
                 return LazyException(
-                    self.exception(
-                        "No value provided for %s" % (self.formkey,)
-                    )
+                    self.exception("No value provided for %s" % (self.formkey,))
                 )
             else:
                 return self.default
