@@ -681,6 +681,9 @@ class Route(object):
         lambda: defaultdict(list)
     )
 
+    #: Always provide an positional ``request`` argument to views
+    provide_request = False
+
     def __init__(
         self,
         pattern,
@@ -866,7 +869,7 @@ class Route(object):
         state["_cached_dviews"] = WeakKeyDictionary()
         return state
 
-    def fallthrough_on(self, *status_codes):
+    def fallthrough_on(self, status_codes):
         newroute = copy(self)
         newroute.fallthrough_statuses = {int(s) for s in status_codes}
         return newroute
@@ -1124,6 +1127,14 @@ class Route(object):
             return _decorator
 
 
+class RRoute(Route):
+    """
+    A subclass of :class:`fresco.routing.Route` that always provides an initial
+    `request` argument to the view.
+    """
+    provide_request = True
+
+
 def split_iter(pattern, string):
     """
     Generate alternate strings and match objects for all occurances of
@@ -1411,6 +1422,8 @@ class RouteCollection(MutableSequence):
                 route_kwargs = route.view_kwargs
 
             args = route_args + traversal_args
+            if route.provide_request:
+                args = (request,) + args
             kwargs = dict(traversal_kwargs, **route_kwargs)
 
             if isinstance(route, DelegateRoute):
