@@ -14,6 +14,7 @@
 #
 from decimal import Decimal
 from tempfile import NamedTemporaryFile
+from tempfile import TemporaryDirectory
 from unittest.mock import Mock
 import contextlib
 import os
@@ -143,10 +144,15 @@ class TestLoadOptions:
         def optionsdir():
             def loadopts(sources="*", tags=[], strict=False, **kw):
                 return Options().load(
-                    str(t / sources), tags, strict=False, **kw
+                    str(sources), tags, strict=False, **kw
                 )
 
-            yield loadopts
+            saved = os.getcwd()
+            os.chdir(t)
+            try:
+                yield loadopts
+            finally:
+                os.chdir(saved)
 
         if expected:
             with optionsdir() as loadopts:
@@ -214,3 +220,10 @@ class TestLoadOptions:
             options.onload(mock)
             options.load(str(pathlib.Path(tmpdir) / "*"))
             assert mock.called
+
+    def test_it_sets_directory(self, tmpdir):
+        with self.check_loadoptions(tmpdir, {"a.txt": "a = 1"}) as loadopts:
+            with TemporaryDirectory() as tmpdir2:
+                os.chdir(tmpdir2)
+                assert loadopts("*") == {}
+                assert loadopts("*", dir=tmpdir) == {'a': 1}
