@@ -54,9 +54,7 @@ class TestRequestProperties(object):
 
     def test_as_string(self):
         with context("http://example.org/foo?bar=baz") as c:
-            assert (
-                str(c.request) == "<Request GET http://example.org/foo?bar=baz>"
-            )
+            assert str(c.request) == "<Request GET http://example.org/foo?bar=baz>"
 
     def test_url_returns_full_url(self):
         with context("http://example.org/foo?bar=baz") as c:
@@ -127,6 +125,18 @@ class TestRequestProperties(object):
         ) as c:
             c.request.get_json(parse_int=lambda s: s + "!") == {"foo": "1!"}
 
+    def test_get_does_type_conversion(self):
+        with context(
+            QUERY_STRING="x=10",
+            CONTENT_LENGTH="10",
+            CONTENT_TYPE="application/broken",
+        ) as c:
+            assert c.request.get("x") == "10"
+            assert c.request.get("x", type=int) == 10
+            with pytest.raises(exceptions.BadRequest):
+                c.request.get("y", type=int)
+            assert c.request.get("y", None, type=int) is None
+
     def test_is_secure_returns_correct_value(self):
         with context("https://example.org/") as c:
             assert c.request.is_secure is True
@@ -146,9 +156,11 @@ class TestRequestProperties(object):
             with context("http://example.org/?a=four") as c:
                 c.request.getint("a")
 
+        with pytest.raises(exceptions.BadRequest):
+            with context("http://example.org/?a=four") as c:
+                assert c.request.getint("a", 0) == 0
+
     def test_getint_returns_default(self):
-        with context("http://example.org/?a=four") as c:
-            assert c.request.getint("a", 0) == 0
         with context("http://example.org/") as c:
             assert c.request.getint("a", 0) == 0
 
@@ -163,10 +175,7 @@ class TestPathEncoding(object):
     def test_url_is_quoted(self):
 
         with context(SCRIPT_NAME=fixtures.wsgi_unicode_path, PATH_INFO="") as c:
-            assert (
-                c.request.url
-                == "http://localhost" + fixtures.quoted_unicode_path
-            )
+            assert c.request.url == "http://localhost" + fixtures.quoted_unicode_path
 
     def test_application_url_is_quoted(self):
 
@@ -220,23 +229,15 @@ class TestMakeURL(object):
 
     def test_it_doesnt_double_quote_request_url(self):
         with context(SCRIPT_NAME="/script name", PATH_INFO="/path info") as c:
-            assert (
-                c.request.make_url()
-                == "http://localhost/script%20name/path%20info"
-            )
+            assert c.request.make_url() == "http://localhost/script%20name/path%20info"
 
     def test_it_doesnt_double_quote_supplied_path_info(self):
         with context() as c:
-            assert (
-                c.request.make_url(PATH_INFO="/x y") == "http://localhost/x%20y"
-            )
+            assert c.request.make_url(PATH_INFO="/x y") == "http://localhost/x%20y"
 
     def test_can_replace_path(self):
         with context(SCRIPT_NAME="/script", PATH_INFO="/pathinfo") as c:
-            assert (
-                c.request.make_url(path="/foo bar")
-                == "http://localhost/foo%20bar"
-            )
+            assert c.request.make_url(path="/foo bar") == "http://localhost/foo%20bar"
 
     def test_it_joins_path(self):
         with context(SCRIPT_NAME="/script name", PATH_INFO="/path info/") as c:
@@ -276,10 +277,7 @@ class TestMakeURL(object):
     def test_unicode_query(self):
         e = b"\xc3\xa9".decode("utf8")  # e-acute
         with context() as c:
-            assert (
-                c.request.make_url(query={"e": e})
-                == "http://localhost/?e=%C3%A9"
-            )
+            assert c.request.make_url(query={"e": e}) == "http://localhost/?e=%C3%A9"
 
     def test_it_quotes_paths(self):
         with context() as c:
@@ -288,8 +286,7 @@ class TestMakeURL(object):
     def test_replace_query_replaces_existing(self):
         with context(QUERY_STRING="a=1") as c:
             assert (
-                c.request.make_url(query_replace={"a": "2"})
-                == "http://localhost/?a=2"
+                c.request.make_url(query_replace={"a": "2"}) == "http://localhost/?a=2"
             )
 
     def test_replace_query_adds_new_value(self):
@@ -416,10 +413,7 @@ class TestMultipart(object):
         with FrescoApp().requestcontext(**self.request_args) as c:
             request = c.request
 
-        assert (
-            request.files["uploaded_file"].headers["content-type"]
-            == "text/plain"
-        )
+        assert request.files["uploaded_file"].headers["content-type"] == "text/plain"
         assert request.files["uploaded_file"].filename == self.filename
 
     def test_quotes_in_input_names_are_decoded(self):
