@@ -215,9 +215,7 @@ class TestJSONPayload(object):
     def test_it_returns_a_default_value(self):
         view = Mock(return_value=Response())
         app = FrescoApp()
-        app.route(
-            "/", POST, view, x=routeargs.JSONPayload(default="default value")
-        )
+        app.route("/", POST, view, x=routeargs.JSONPayload(default="default value"))
         with app.requestcontext_post("/"):
             app.view()
         x = view.call_args[1]["x"]
