@@ -180,14 +180,10 @@ class TestRouteBeforeHooks(object):
 
 class TestRouteViewFilters(object):
     def exclaim(self, response):
-        return response.replace(
-            content=[b"".join(response.content_iterator) + b"!"]
-        )
+        return response.replace(content=[b"".join(response.content_iterator) + b"!"])
 
     def ask(self, response):
-        return response.replace(
-            content=[b"".join(response.content_iterator) + b"?"]
-        )
+        return response.replace(content=[b"".join(response.content_iterator) + b"?"])
 
     def test_filter_is_applied(self):
         views = fixtures.CBV("test")
@@ -217,9 +213,7 @@ class TestRouteViewFilters(object):
     def test_it_applies_chained_filter_calls_in_order(self):
         app = FrescoApp()
         views = fixtures.CBV("test")
-        app.route("/", GET, views.index_html).filter(self.ask).filter(
-            self.exclaim
-        )
+        app.route("/", GET, views.index_html).filter(self.ask).filter(self.exclaim)
         with app.requestcontext("/"):
             assert list(app.view().content_iterator) == [b"test?!"]
 
@@ -250,9 +244,7 @@ class TestRouteDecorators(object):
         views = fixtures.CBV("test")
 
         app = FrescoApp()
-        app.route(
-            "/decorated", GET, views.index_html, decorators=[self.exclaim]
-        )
+        app.route("/decorated", GET, views.index_html, decorators=[self.exclaim])
         app.route("/plain", GET, views.index_html)
 
         with app.requestcontext("/decorated"):
@@ -299,14 +291,9 @@ class TestRouteDecorators(object):
 
         views = fixtures.CBV("test")
         app = FrescoApp()
-        app.route(
-            "/decorated", GET, views.index_html, decorators=[self.exclaim]
-        )
+        app.route("/decorated", GET, views.index_html, decorators=[self.exclaim])
         with app.requestcontext():
-            assert (
-                urlfor(views.index_html, _app=app)
-                == "http://localhost/decorated"
-            )
+            assert urlfor(views.index_html, _app=app) == "http://localhost/decorated"
 
     def test_using_wraps_with_viewspec_doesnt_raise_AttributeError(self):
         def decorator(func):
@@ -317,9 +304,7 @@ class TestRouteDecorators(object):
             return decorator
 
         class Views(object):
-            __routes__ = (
-                Route("/", GET, "index_html", decorators=[decorator]),
-            )
+            __routes__ = (Route("/", GET, "index_html", decorators=[decorator]),)
 
             def index_html(self):
                 return Response(["hello"])
@@ -503,9 +488,7 @@ class TestRouteCollection(object):
         v = MyViews()
         app = FrescoApp()
         app.include("/", v)
-        assert [r.route.getview(GET) for r in app.get_routes("/", GET)] == [
-            v.view
-        ]
+        assert [r.route.getview(GET) for r in app.get_routes("/", GET)] == [v.view]
 
     def test_routecollections_in_classes_can_be_manipulated(self):
         class MyViews(object):
@@ -529,9 +512,7 @@ class TestRouteCollection(object):
         ]
 
     def test_add_prefix_returns_prefixed_collection(self):
-        rc = RouteCollection(
-            [Route("/fish", GET, None), Route("/beans", GET, None)]
-        )
+        rc = RouteCollection([Route("/fish", GET, None), Route("/beans", GET, None)])
         prefixed = rc.add_prefix("/jelly")
         assert [str(r.pattern) for r in prefixed] == [
             "/jelly/fish",
@@ -615,9 +596,7 @@ class TestRouteCollection(object):
                 return []
 
             app = FrescoApp()
-            app.route_wsgi(
-                mountpoint, wsgiapp, rewrite_script_name=rewrite_script_name
-            )
+            app.route_wsgi(mountpoint, wsgiapp, rewrite_script_name=rewrite_script_name)
             with app.requestcontext(path):
                 app.view()
             assert wsgiapp.called is True  # type: ignore
@@ -626,16 +605,14 @@ class TestRouteCollection(object):
         test_wsgi_app("/prefix", "/prefix/", "/prefix", "/")
         test_wsgi_app("/", "/", "", "/")
         test_wsgi_app("/", "/foo", "", "/foo")
-        test_wsgi_app(
-            "/prefix", "/prefix", "", "/prefix", rewrite_script_name=False
-        )
+        test_wsgi_app("/prefix", "/prefix", "", "/prefix", rewrite_script_name=False)
 
     def test_fallthrough_can_be_applied_to_collection(self):
         a = Route("/fee", GET=lambda: Response(status=204))
         a = Route("/fie", GET=lambda: Response(status=204))
         b = Route("/foe", GET=lambda: Response(status=204))
         rc = RouteCollection([a, b])
-        rc = rc.fallthrough_on("204")
+        rc = rc.fallthrough_on(["204"])
         assert all(r.fallthrough_statuses == {204} for r in rc.__routes__)
 
 
@@ -654,10 +631,7 @@ class TestRoutefor(object):
         app = FrescoApp()
         route = app.route("/myviewfunc", GET, fixtures.module_level_function)
         with app.requestcontext():
-            assert (
-                routefor("fresco.tests.fixtures.module_level_function")
-                == route
-            )
+            assert routefor("fresco.tests.fixtures.module_level_function") == route
 
     def test_routefor_generates_first_route(self):
         def myviewfunc():
@@ -766,23 +740,17 @@ class TestDelegatedRoutes(object):
         outer.delegate("/<o:str>", inner, name="delegation")
 
         with outer.requestcontext("/foo/bar"):
-            assert (
-                outer.pathfor("delegation:inner-route", o="x", i="y") == "/x/y"
-            )
+            assert outer.pathfor("delegation:inner-route", o="x", i="y") == "/x/y"
 
     def test_pathfor_with_dynamic_delegated_route(self):
 
         view = Mock(return_value=Response())
 
         def routecollectionfactory(*args, **kwargs):
-            return RouteCollection(
-                [Route("/<i:str>", GET, view, name="inner-route")]
-            )
+            return RouteCollection([Route("/<i:str>", GET, view, name="inner-route")])
 
         rc = RouteCollection()
-        rc.delegate(
-            "/<o:str>", routecollectionfactory, name="delegation", dynamic=True
-        )
+        rc.delegate("/<o:str>", routecollectionfactory, name="delegation", dynamic=True)
 
         assert rc.pathfor("delegation:inner-route", o="x", i="y") == "/x/y"
 
@@ -791,9 +759,7 @@ class TestDelegatedRoutes(object):
         view = Mock(return_value=Response())
 
         def routecollectionfactory(factoryarg1, factoryarg2):
-            return RouteCollection(
-                [Route("/<i:str>", GET, view, name="inner-route")]
-            )
+            return RouteCollection([Route("/<i:str>", GET, view, name="inner-route")])
 
         rc = RouteCollection()
         rc.delegate(
@@ -902,6 +868,18 @@ class TestConverters(object):
             assert view.call_args == (("bar",), {}), view.call_args
 
 
+class TestRRoute:
+    def test_it_passes_the_request(self):
+        from fresco.routing import RRoute
+
+        view = Mock(return_value=Response())
+        app = FrescoApp()
+        app.add_route(RRoute("/", GET=view))
+        with app.requestcontext("/") as c:
+            app.view()
+            assert view.call_args == ((c.request,), {})
+
+
 class TestViewArgs(object):
     def test_it_uses_args(self):
         routes = RouteCollection([Route("/", GET, None, args=(1, 2))])
@@ -916,9 +894,7 @@ class TestViewArgs(object):
         ]
 
     def test_it_appends_args_extracted_from_path(self):
-        routes = RouteCollection(
-            [Route("/<:int>", GET, None, view_args=(1, 2))]
-        )
+        routes = RouteCollection([Route("/<:int>", GET, None, view_args=(1, 2))])
         assert list(routes.get_routes("/3", GET)) == [
             tms.InstanceOf(RouteTraversal, args=(1, 2, 3))
         ]
@@ -958,9 +934,7 @@ class TestViewKwargs(object):
         ]
 
     def test_it_keeps_traversal_kwargs_separate(self):
-        routes = RouteCollection(
-            [Route("/<x:int>", GET, None, view_kwargs={"y": 1})]
-        )
+        routes = RouteCollection([Route("/<x:int>", GET, None, view_kwargs={"y": 1})])
         assert list(routes.get_routes("/2", GET)) == [
             tms.InstanceOf(
                 RouteTraversal,
@@ -1006,9 +980,7 @@ class TestRouteClassIsPluggable(object):
         routes.route("/", GET, myview)
 
         assert list(routes.get_routes("/", GET)) == [
-            tms.InstanceOf(
-                RouteTraversal, route=tms.InstanceOf(self.CustomRoute)
-            )
+            tms.InstanceOf(RouteTraversal, route=tms.InstanceOf(self.CustomRoute))
         ]
 
     def test_it_uses_route_class_in_decorator(self):
@@ -1020,9 +992,7 @@ class TestRouteClassIsPluggable(object):
             pass
 
         assert list(routes.get_routes("/", GET)) == [
-            tms.InstanceOf(
-                RouteTraversal, route=tms.InstanceOf(self.CustomRoute)
-            )
+            tms.InstanceOf(RouteTraversal, route=tms.InstanceOf(self.CustomRoute))
         ]
 
     def test_custom_route_class_survives_include(self):
@@ -1036,9 +1006,7 @@ class TestRouteClassIsPluggable(object):
         routes2.include("/incl", routes)
 
         assert list(routes2.get_routes("/incl/", GET)) == [
-            tms.InstanceOf(
-                RouteTraversal, route=tms.InstanceOf(self.CustomRoute)
-            )
+            tms.InstanceOf(RouteTraversal, route=tms.InstanceOf(self.CustomRoute))
         ]
 
 
