@@ -21,6 +21,8 @@ from mock import Mock
 from tempfile import mkstemp
 from fresco import FrescoApp
 from fresco.static import serve_static_file
+from fresco.util.wsgi import ClosingIterator
+from fresco.util.wsgi import apply_request
 
 
 class TestServeStaticFile:
@@ -99,9 +101,15 @@ class TestServeStaticFile:
 
     def test_filewrapper_used_if_present(self):
         with FrescoApp().requestcontext() as c:
-            file_wrapper = Mock(return_value=[])
+
+            def closefile():
+                file_wrapper.call_args.args[0].close()
+
+            file_wrapper = Mock()
+            file_wrapper.return_value = ClosingIterator([], closefile)
             c.request.environ["wsgi.file_wrapper"] = file_wrapper
-            serve_static_file(self.tmpname)
+            response = serve_static_file(self.tmpname)
+            apply_request(c.request, response)
 
         assert file_wrapper.call_count == 1
 
