@@ -43,7 +43,7 @@ from fresco.util.io import (
     PutbackInput,
     DelimitedInput,
 )
-from fresco.util.wsgi import unicode_to_environ
+from fresco.util.wsgi import str_to_environ
 
 KB = 1024
 MB = 1024 * KB
@@ -821,7 +821,7 @@ def encode_multipart(data=None, files=None, charset="UTF-8", **kwargs):
     :param data: POST data to be encoded, either a dict or list of
                  ``(name, value)`` tuples.
 
-    :param charset: Encoding used for any unicode values encountered in
+    :param charset: Encoding used for any string values encountered in
                     ``data``
 
     :param files: list of ``(name, filename, content_type, data)`` tuples.
@@ -896,7 +896,7 @@ def encode_multipart(data=None, files=None, charset="UTF-8", **kwargs):
     post_data.seek(0)
     wsgienv = {
         "CONTENT_LENGTH": str(length),
-        "CONTENT_TYPE": unicode_to_environ(
+        "CONTENT_TYPE": str_to_environ(
             "multipart/form-data; boundary=" + boundary.decode("ascii")
         ),
     }
