@@ -17,12 +17,15 @@
 Utilities for wrapping IO streams. These are used internally by
 fresco when parsing wsgi request input streams.
 """
-from __future__ import absolute_import
-
-from io import BytesIO, IOBase
+from io import BytesIO
+from io import IOBase
 
 from collections import deque
 from tempfile import TemporaryFile
+from typing import Callable
+from typing import Deque
+from typing import IO
+from typing import List
 from shutil import copyfileobj
 
 
@@ -32,14 +35,20 @@ class ReadlinesMixin(object):
     underlying readline method.
     """
 
+    readline: Callable
+
     def readlines(self, sizehint=0):
-        size = 0
-        lines = []
-        for line in iter(self.readline, b''):
-            lines.append(line)
-            size += len(line)
-            if 0 < sizehint <= size:
-                break
+        if sizehint > 0:
+            size = 0
+            lines: List[bytes] = []
+            append = lines.append
+            for line in iter(self.readline, b""):
+                append(line)
+                size += len(line)
+                if size >= sizehint:
+                    break
+        else:
+            lines = list(iter(self.readline, b""))
         return lines
 
     def __iter__(self):
@@ -53,19 +62,16 @@ class ReadlinesMixin(object):
 
 
 class Reader(IOBase):
-
     def readable(self):
         return True
 
 
 class Seeker(IOBase):
-
     def seekable(self):
         return True
 
 
 class Writer(IOBase):
-
     def writable(self):
         return True
 
@@ -94,14 +100,14 @@ class PutbackInput(Reader, ReadlinesMixin):
         Initialize a ``PutbackInput`` object from raw input stream ``raw``.
         """
         self._raw = raw
-        self._putback = deque()
+        self._putback: Deque[bytes] = deque()
 
     def read(self, size=-1):
         """
         Read and return up to ``size`` bytes.
         """
         if size < 0:
-            result = b''.join(self._putback) + self._raw.read()
+            result = b"".join(self._putback) + self._raw.read()
             self._putback.clear()
             return result
 
@@ -120,7 +126,7 @@ class PutbackInput(Reader, ReadlinesMixin):
         if remaining > 0:
             buf.append(self._raw.read(remaining))
 
-        return b''.join(buf)
+        return b"".join(buf)
 
     def readline(self, size=-1):
         """
@@ -138,12 +144,12 @@ class PutbackInput(Reader, ReadlinesMixin):
                     chunk, p = chunk[:-excess], chunk[-excess:]
                     self.putback(p)
 
-            pos = chunk.find(b'\n')
+            pos = chunk.find(b"\n")
             if pos >= 0:
-                chunk, p = chunk[:(pos + 1)], chunk[(pos + 1):]
+                chunk, p = chunk[: (pos + 1)], chunk[(pos + 1) :]
                 self.putback(p)
                 buf.append(chunk)
-                return b''.join(buf)
+                return b"".join(buf)
 
             buf.append(chunk)
             remaining -= len(chunk)
@@ -153,7 +159,7 @@ class PutbackInput(Reader, ReadlinesMixin):
         else:
             buf.append(self._raw.readline())
 
-        return b''.join(buf)
+        return b"".join(buf)
 
     def putback(self, data):
         """
@@ -269,7 +275,7 @@ class DelimitedInput(Reader, ReadlinesMixin):
         Initialize an instance of ``DelimitedInput``.
         """
 
-        if not getattr(raw, 'putback', None):
+        if not getattr(raw, "putback", None):
             raise TypeError("Need an instance of PutbackInput")
 
         self._raw = raw
@@ -278,22 +284,21 @@ class DelimitedInput(Reader, ReadlinesMixin):
         self.delimiter_found = False
         self.delimiter_len = len(delimiter)
 
-    def read(self, size=-1):
+    def read(self, size=-1, MAX_BLOCK_SIZE=8 * 1024) -> bytes:
         """
         Return up to ``size`` bytes of data from the stream until EOF or
         ``delimiter`` is reached.
         """
         if self.delimiter_found:
-            return b''
-        MAX_BLOCK_SIZE = 8 * 1024
+            return b""
         if size == -1:
-            return ''.join(iter(lambda: self.read(MAX_BLOCK_SIZE), b''))
+            return b"".join(iter(lambda: self.read(MAX_BLOCK_SIZE), b""))
 
         data = self._raw.read(size + self.delimiter_len)
         pos = data.find(self.delimiter)
         if pos >= 0:
             if self.consume_delimiter:
-                putback = data[pos + self.delimiter_len:]
+                putback = data[pos + self.delimiter_len :]
             else:
                 putback = data[pos:]
             self.delimiter_found = True
@@ -301,8 +306,8 @@ class DelimitedInput(Reader, ReadlinesMixin):
             return data[:pos]
 
         elif len(data) == size + self.delimiter_len:
-            self._raw.putback(data[-self.delimiter_len:])
-            return data[:-self.delimiter_len]
+            self._raw.putback(data[-self.delimiter_len :])
+            return data[: -self.delimiter_len]
 
         else:
             return data
@@ -314,7 +319,7 @@ class DelimitedInput(Reader, ReadlinesMixin):
         """
 
         if self.delimiter_found:
-            return b''
+            return b""
         line = self._raw.readline(size)
         extra = self._raw.read(len(self.delimiter))
         if self.delimiter not in line + extra:
@@ -325,15 +330,15 @@ class DelimitedInput(Reader, ReadlinesMixin):
         pos = data.find(self.delimiter)
         if pos >= 0:
             if self.consume_delimiter:
-                putback = data[pos + len(self.delimiter):]
+                putback = data[pos + len(self.delimiter) :]
             else:
                 putback = data[pos:]
             self.delimiter_found = True
             self._raw.putback(putback)
             return data[:pos]
         elif len(data) == size + len(self.delimiter):
-            self._raw.putback(data[-len(self.delimiter):])
-            return data[:-len(self.delimiter)]
+            self._raw.putback(data[-len(self.delimiter) :])
+            return data[: -len(self.delimiter)]
         else:
             return data
 
@@ -356,7 +361,7 @@ class ExpandableOutput(Reader, Writer, Seeker):
         """
         Initialize an ``ExpandableOutput`` instance.
         """
-        self._raw = BytesIO()
+        self._raw: IO[bytes] = BytesIO()
         self.bufsize = bufsize
         self.write = self.write_stringio
         self.exceeded_bufsize = False
@@ -383,8 +388,10 @@ class ExpandableOutput(Reader, Writer, Seeker):
         """
         ``write``, optimized for the BytesIO backend.
         """
-        if isinstance(self._raw, BytesIO) \
-           and self._raw.tell() + len(data) > self.bufsize:
+        if (
+            isinstance(self._raw, BytesIO)
+            and self._raw.tell() + len(data) > self.bufsize
+        ):
             self.switch_to_file_storage()
             return self.write_file(data)
         return self._raw.write(data)
