@@ -21,8 +21,14 @@ from io import BytesIO
 from urllib.parse import unquote
 from urllib.parse import urlparse
 from typing import List
+from typing import Optional
+from typing import Tuple
 import sys
 
+from fresco.typing import ExcInfoTuple
+from fresco.typing import HeadersList
+from fresco.typing import WSGICallable
+
 __all__ = [
     "environ_to_unicode",
     "unicode_to_environ",
@@ -35,7 +41,6 @@ __all__ = [
     "make_environ",
 ]
 
-
 #: The core keys expected in the WSGI environ dict, as defined by PEP3333
 WSGI_KEYS = set(
     [
@@ -251,9 +256,7 @@ class StartResponseWrapper(object):
         Invoke the wrapped WSGI ``start_response`` function.
         """
         try:
-            write = self.start_response(
-                self.status, self.headers, self.exc_info
-            )
+            write = self.start_response(self.status, self.headers, self.exc_info)
             write(self.buf.getvalue())
             return write
         finally:
@@ -414,3 +417,26 @@ def make_environ(url="/", environ=None, wsgi_input=b"", **kwargs):
         if v is None and "." not in k:
             del environ[k]
     return environ
+
+
+def apply_request(
+    request, wsgicallable: WSGICallable
+) -> Tuple[str, HeadersList, Optional[ExcInfoTuple], List[bytes]]:
+    """
+    Execute ``wsgicallable`` with the given request, exhaust and close the
+    content iterator and return the result.
+    """
+
+    _start_response_result: List[Tuple[str, HeadersList, Optional[ExcInfoTuple]]] = []
+
+    def start_response(
+        status: str, headers: HeadersList, exc_info: Optional[ExcInfoTuple] = None
+    ):
+        _start_response_result.append((status, headers, exc_info))
+
+    contentiter = wsgicallable(request.environ, start_response)
+    assert len(_start_response_result) == 1
+    content = list(contentiter)
+    if hasattr(contentiter, "close"):
+        contentiter.close()  # type: ignore
+    return _start_response_result[0] + (content,)
